@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c 6498 2008-09-07 13:50:57Z pborelli $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +41,7 @@
 #include <fcntl.h>
 #include <string.h>
 
-#include <glib/gunicode.h>
+#include <glib.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
@@ -482,51 +482,6 @@ gedit_utils_unescape_search_text (const gchar *text)
 	return g_string_free (str, FALSE);
 }
 
-#define GEDIT_STDIN_BUFSIZE 1024
-
-gchar *
-gedit_utils_get_stdin (void)
-{
-	GString * file_contents;
-	gchar *tmp_buf = NULL;
-	guint buffer_length;
-	fd_set rfds;
-	struct timeval tv;
-	
-	FD_ZERO (&rfds);
-	FD_SET (0, &rfds);
-
-	/* wait for 1/4 of a second */
-	tv.tv_sec = 0;
-	tv.tv_usec = STDIN_DELAY_MICROSECONDS;
-
-	if (select (1, &rfds, NULL, NULL, &tv) != 1)
-		return NULL;
-
-	tmp_buf = g_new0 (gchar, GEDIT_STDIN_BUFSIZE + 1);
-	g_return_val_if_fail (tmp_buf != NULL, FALSE);
-
-	file_contents = g_string_new (NULL);
-	
-	while (feof (stdin) == 0)
-	{
-		buffer_length = fread (tmp_buf, 1, GEDIT_STDIN_BUFSIZE, stdin);
-		tmp_buf [buffer_length] = '\0';
-		g_string_append (file_contents, tmp_buf);
-
-		if (ferror (stdin) != 0)
-		{
-			g_free (tmp_buf);
-			g_string_free (file_contents, TRUE);
-			return NULL;
-		}
-	}
-
-	fclose (stdin);
-
-	return g_string_free (file_contents, FALSE);
-}
-
 void 
 gedit_warning (GtkWindow *parent, const gchar *format, ...)
 {
@@ -612,9 +567,10 @@ gedit_utils_escape_underscores (const gchar* text,
 
 /* the following functions are taken from eel */
 
-gchar *
-gedit_utils_str_middle_truncate (const gchar *string,
-				 guint        truncate_length)
+static gchar *
+gedit_utils_str_truncate (const gchar *string,
+			  guint        truncate_length,
+			  gboolean middle)
 {
 	GString     *truncated;
 	guint        length;
@@ -647,17 +603,41 @@ gedit_utils_str_middle_truncate (const gchar *string,
 	}
 
 	/* Find the 'middle' where the truncation will occur. */
-	num_left_chars = (truncate_length - delimiter_length) / 2;
-	right_offset = n_chars - truncate_length + num_left_chars + delimiter_length;
+	if (middle)
+	{
+		num_left_chars = (truncate_length - delimiter_length) / 2;
+		right_offset = n_chars - truncate_length + num_left_chars + delimiter_length;
 
-	truncated = g_string_new_len (string,
-				      g_utf8_offset_to_pointer (string, num_left_chars) - string);
-	g_string_append (truncated, delimiter);
-	g_string_append (truncated, g_utf8_offset_to_pointer (string, right_offset));
-		
+		truncated = g_string_new_len (string,
+					      g_utf8_offset_to_pointer (string, num_left_chars) - string);
+		g_string_append (truncated, delimiter);
+		g_string_append (truncated, g_utf8_offset_to_pointer (string, right_offset));
+	}
+	else
+	{
+		num_left_chars = truncate_length - delimiter_length;
+		truncated = g_string_new_len (string,
+					      g_utf8_offset_to_pointer (string, num_left_chars) - string);
+		g_string_append (truncated, delimiter);
+	}
+	
 	return g_string_free (truncated, FALSE);
 }
 
+gchar *
+gedit_utils_str_middle_truncate (const gchar *string,
+				 guint        truncate_length)
+{
+	return gedit_utils_str_truncate (string, truncate_length, TRUE);
+}
+
+gchar *
+gedit_utils_str_end_truncate (const gchar *string,
+			      guint        truncate_length)
+{
+	return gedit_utils_str_truncate (string, truncate_length, FALSE);
+}
+
 gchar *
 gedit_utils_make_valid_utf8 (const char *name)
 {
@@ -665,6 +645,8 @@ gedit_utils_make_valid_utf8 (const char *name)
 	const char *remainder, *invalid;
 	int remaining_bytes, valid_bytes;
 
+	g_return_val_if_fail (name != NULL, NULL);
+
 	string = NULL;
 	remainder = name;
 	remaining_bytes = strlen (name);
@@ -704,7 +686,9 @@ gedit_utils_uri_get_dirname (const gchar *uri)
 	gchar *res;
 	gchar *str;
 
-	// CHECK: does it work with uri chaining? - Paolo
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	/* CHECK: does it work with uri chaining? - Paolo */
 	str = g_path_get_dirname (uri);
 	g_return_val_if_fail (str != NULL, ".");
 
@@ -722,6 +706,71 @@ gedit_utils_uri_get_dirname (const gchar *uri)
 	return res;
 }
 
+/**
+ * gedit_utils_location_get_dirname_for_display
+ * @file: the location
+ *
+ * Returns a string suitable to be displayed in the UI indicating
+ * the name of the directory where the file is located.
+ * For remote files it may also contain the hostname etc.
+ * For local files it tries to replace the home dir with ~.
+ *
+ * Returns: a string to display the dirname
+ */
+gchar *
+gedit_utils_location_get_dirname_for_display (GFile *location)
+{
+	gchar *uri;
+	gchar *res;
+	GMount *mount;
+
+	g_return_val_if_fail (location != NULL, NULL);
+
+	/* we use the parse name, that is either the local path
+	 * or an uri but which is utf8 safe */
+	uri = g_file_get_parse_name (location);
+
+	/* FIXME: this is sync... is it a problem? */
+	mount = g_file_find_enclosing_mount (location, NULL, NULL);
+	if (mount != NULL)
+	{
+		gchar *mount_name;
+		gchar *path;
+
+		mount_name = g_mount_get_name (mount);
+		g_object_unref (mount);
+
+		/* obtain the "path" patrt of the uri */
+		if (gedit_utils_decode_uri (uri,
+					    NULL, NULL,
+					    NULL, NULL,
+					    &path))
+		{
+			gchar *dirname;
+			
+			dirname = gedit_utils_uri_get_dirname (path);
+			res = g_strdup_printf ("%s %s", mount_name, dirname);
+
+			g_free (path);
+			g_free (dirname);
+			g_free (mount_name);
+		}
+		else
+		{
+			res = mount_name;
+		}
+	}
+	else
+	{
+		/* fallback for local files or uris without mounts */
+		res = gedit_utils_uri_get_dirname (uri);
+	}
+
+	g_free (uri);
+
+	return res;
+}
+
 gchar *
 gedit_utils_replace_home_dir_with_tilde (const gchar *uri)
 {
@@ -992,8 +1041,7 @@ gedit_utils_is_valid_uri (const gchar *uri)
 }
 
 static GtkWidget *
-handle_builder_error (const gchar *message,
-		      ...)
+handle_builder_error (const gchar *message, ...)
 {
 	GtkWidget *label;
 	gchar *msg;
@@ -1001,16 +1049,18 @@ handle_builder_error (const gchar *message,
 	va_list args;
 
 	va_start (args, message);
-	va_arg (args, const gchar *);
 	msg_plain = g_strdup_vprintf (message, args);
+	va_end (args);
+
+	label = gtk_label_new (NULL);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
 	msg = g_strconcat ("<span size=\"large\" weight=\"bold\">",
-			msg_plain, "</span>\n\n",
-			_("Please check your installation."), NULL);
-	label = gtk_label_new (msg);
+			   msg_plain, "</span>\n\n",
+			   _("Please check your installation."),
+			   NULL);
 
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	gtk_label_set_markup (GTK_LABEL (label), msg);
 
 	g_free (msg_plain);
 	g_free (msg);
@@ -1192,11 +1242,11 @@ gedit_utils_basename_for_display (gchar const *uri)
 	gchar *name;
 	GFile *gfile;
 	gchar *hn;
-	
+
 	g_return_val_if_fail (uri != NULL, NULL);
-	
+
 	gfile = g_file_new_for_uri (uri);
-	
+
 	/* First, try to query the display name, but only on local files */
 	if (g_file_has_uri_scheme (gfile, "file"))
 	{
@@ -1243,11 +1293,16 @@ gedit_utils_basename_for_display (gchar const *uri)
 	{
 		/* display '/ on <host>' using the decoded host */
 		gchar *hn_utf8;
-		hn_utf8 = gedit_utils_make_valid_utf8 (hn);
-		
+
+		if  (hn != NULL)
+			hn_utf8 = gedit_utils_make_valid_utf8 (hn);
+		else
+			/* we should never get here */
+			hn_utf8 = g_strdup ("?");
+
 		/* Translators: '/ on <remote-share>' */
 		name = g_strdup_printf (_("/ on %s"), hn_utf8);
-		
+
 		g_free (hn_utf8);
 		g_free (hn);
 	}
